View source: R/max_geboes_score.R
| max_geboes_score | R Documentation |
Since the values ending in ".0" indicate no effect, they are not considered in which values is the maximum. In other words, "2.0" < "1.1".
max_geboes_score(x, all_categories = TRUE, na.rm = TRUE)
x |
A character vector of Geboes score grades |
all_categories |
Must |
na.rm |
a logical indicating whether missing values should be removed. |
Typical use of max_geboes_score() is to find the maximum for a single
person at a single time. For that, the all_categories argument ensures
that each category is present exactly once.
The maximum value of x where values ending in ".0" are considered
as "0.0"
max_geboes_score(c("0.0", "1.2", "2A.2", "2B.1", "3.3", "4.1", "5.0")) # 4.1
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.